summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtp.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.c2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c8
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h12
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c28
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h16
8 files changed, 36 insertions, 36 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c
index 80e07682..1ac35d9c 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c
@@ -101,7 +101,7 @@ void ortp_scheduler_init()
sigset_t set;
sigemptyset(&set);
sigaddset(&set,SIGALRM);
- sigprocmask(SIG_BLOCK,&set,NULL);
+ sigproctqmask(SIG_BLOCK,&set,NULL);
#endif /* __hpux */
if (!g_thread_supported()) g_thread_init(NULL);
__ortp_scheduler=rtp_scheduler_new();
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtp.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtp.h
index 625d2111..f67409d8 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtp.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtp.h
@@ -26,7 +26,7 @@
-#define RTP_MAX_RQ_SIZE 100 /* max number of packet allowed to be enqueued */
+#define RTP_MAX_RTQ_SIZE 100 /* max number of packet allowed to be enqueued */
#define IPMAXLEN 20
#define UDP_MAX_SIZE 65536
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.c
index de6b2e7d..a73aa121 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.c
@@ -104,7 +104,7 @@ rtp_session_init (RtpSession * session, gint mode)
{
memset (session, 0, sizeof (RtpSession));
session->lock = g_mutex_new ();
- session->rtp.max_rq_size = RTP_MAX_RQ_SIZE;
+ session->rtp.max_rq_size = RTP_MAX_RTQ_SIZE;
session->mode = mode;
if ((mode == RTP_SESSION_RECVONLY) || (mode == RTP_SESSION_SENDRECV))
{
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h
index 91cde6a9..106f1fcd 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h
@@ -29,15 +29,15 @@
struct _RtpScheduler {
RtpSession *list; /* list of scheduled sessions*/
- SessionSet all_sessions; /* mask of scheduled sessions */
- gint all_max; /* the highest pos in the all mask */
- SessionSet r_sessions; /* mask of sessions that have a recv event */
+ SessionSet all_sessions; /* tqmask of scheduled sessions */
+ gint all_max; /* the highest pos in the all tqmask */
+ SessionSet r_sessions; /* tqmask of sessions that have a recv event */
gint r_max;
- SessionSet w_sessions; /* mask of sessions that have a send event */
+ SessionSet w_sessions; /* tqmask of sessions that have a send event */
gint w_max;
- SessionSet e_sessions; /* mask of session that have error event */
+ SessionSet e_sessions; /* tqmask of session that have error event */
gint e_max;
- gint max_sessions; /* the number of position in the masks */
+ gint max_sessions; /* the number of position in the tqmasks */
/* GMutex *unblock_select_mutex; */
GCond *unblock_select_cond;
GMutex *lock;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h
index 623b9d10..b4a0b904 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h
@@ -45,7 +45,7 @@ typedef fd_set ortp_fd_set;
do { \
unsigned int __i; \
ortp_fd_set *__arr = (s); \
- for (__i = 0; __i < sizeof (ortp_fd_set) / sizeof (ortp__fd_mask); ++__i) \
+ for (__i = 0; __i < sizeof (ortp_fd_set) / sizeof (ortp__fd_tqmask); ++__i) \
ORTP__FDS_BITS (__arr)[__i] = 0; \
} while (0)
#define ORTP_FD_SET(d, s) (ORTP__FDS_BITS (s)[ORTP__FDELT(d)] |= ORTP__FDMASK(d))
@@ -55,22 +55,22 @@ typedef fd_set ortp_fd_set;
/* The fd_set member is required to be an array of longs. */
-typedef long int ortp__fd_mask;
+typedef long int ortp__fd_tqmask;
/* Number of bits per word of `fd_set' (some code assumes this is 32). */
#define ORTP__FD_SETSIZE 1024
/* It's easier to assume 8-bit bytes than to get CHAR_BIT. */
-#define ORTP__NFDBITS (8 * sizeof (ortp__fd_mask))
+#define ORTP__NFDBITS (8 * sizeof (ortp__fd_tqmask))
#define ORTP__FDELT(d) ((d) / ORTP__NFDBITS)
-#define ORTP__FDMASK(d) ((ortp__fd_mask) 1 << ((d) % ORTP__NFDBITS))
+#define ORTP__FDMASK(d) ((ortp__fd_tqmask) 1 << ((d) % ORTP__NFDBITS))
/* fd_set for select and pselect. */
typedef struct
{
- ortp__fd_mask fds_bits[ORTP__FD_SETSIZE / ORTP__NFDBITS];
+ ortp__fd_tqmask fds_bits[ORTP__FD_SETSIZE / ORTP__NFDBITS];
# define ORTP__FDS_BITS(set) ((set)->fds_bits)
} ortp_fd_set;
@@ -87,9 +87,9 @@ typedef struct _SessionSet SessionSet;
SessionSet * session_set_new();
#define session_set_init(ss) ORTP_FD_ZERO(&(ss)->rtpset)
-#define session_set_set(ss,rtpsession) ORTP_FD_SET((rtpsession)->mask_pos,&(ss)->rtpset)
-#define session_set_is_set(ss,rtpsession) ORTP_FD_ISSET((rtpsession)->mask_pos,&(ss)->rtpset)
-#define session_set_clr(ss,rtpsession) ORTP_FD_CLR((rtpsession)->mask_pos,&(ss)->rtpset)
+#define session_set_set(ss,rtpsession) ORTP_FD_SET((rtpsession)->tqmask_pos,&(ss)->rtpset)
+#define session_set_is_set(ss,rtpsession) ORTP_FD_ISSET((rtpsession)->tqmask_pos,&(ss)->rtpset)
+#define session_set_clr(ss,rtpsession) ORTP_FD_CLR((rtpsession)->tqmask_pos,&(ss)->rtpset)
#define session_set_copy(dest,src) memcpy(&(dest)->rtpset,&(src)->rtpset,sizeof(ortp_fd_set))
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h
index e7702000..81554a06 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h
@@ -177,7 +177,7 @@ struct _RtpSession
RtpSessionMode mode;
struct _RtpScheduler *sched;
guint32 flags;
- gint mask_pos; /* the position in the scheduler mask of RtpSession */
+ gint tqmask_pos; /* the position in the scheduler tqmask of RtpSession */
gpointer user_data;
/* telephony events extension */
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
index 17ff6748..2ea733ac 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
@@ -148,7 +148,7 @@ gpointer rtp_scheduler_schedule(gpointer psched)
g_mutex_unlock(sched->lock);
/* now while the scheduler is going to sleep, the other threads can compute their
- result mask and see if they have to leave, or to wait for next tick*/
+ result tqmask and see if they have to leave, or to wait for next tick*/
//g_message("scheduler: sleeping.");
timer->timer_do();
sched->time_+=sched->timer_inc;
@@ -174,10 +174,10 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
if (sched->max_sessions==0){
g_error("rtp_scheduler_add_session: max_session=0 !");
}
/* find a free pos in the session mask*/
for (i=0;i<sched->max_sessions;i++){
if (!ORTP_FD_ISSET(i,&sched->all_sessions.rtpset)){
- session->mask_pos=i;
+ session->tqmask_pos=i;
session_set_set(&sched->all_sessions,session);
/* make a new session scheduled not blockable if it has not started*/
if (session->flags & RTP_SESSION_RECV_NOT_STARTED)
@@ -229,7 +229,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
}
}
rtp_session_unset_flag(session,RTP_SESSION_IN_SCHEDULER);
/* delete the bit in the mask */
session_set_clr(&sched->all_sessions,session);
rtp_scheduler_unlock(sched);
}
@@ -174,10 +174,10 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
g_error("rtp_scheduler_add_session: max_session=0 !");
}
- /* find a free pos in the session mask*/
+ /* find a free pos in the session tqmask*/
for (i=0;i<sched->max_sessions;i++){
if (!ORTP_FD_ISSET(i,&sched->all_sessions.rtpset)){
@@ -229,7 +229,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
}
rtp_session_unset_flag(session,RTP_SESSION_IN_SCHEDULER);
- /* delete the bit in the mask */
+ /* delete the bit in the tqmask */
session_set_clr(&sched->all_sessions,session);
rtp_scheduler_unlock(sched);
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
index 7b5ad921..bea1a7c9 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
@@ -60,27 +60,27 @@ void session_set_destroy(SessionSet *set)
gint session_set_and(SessionSet *sched_set, gint maxs, SessionSet *user_set, SessionSet *result_set)
{
- guint32 *mask1,*mask2,*mask3;
+ guint32 *tqmask1,*tqmask2,*tqmask3;
gint i=0;
gint j,ret=0;
- mask1=(guint32*)&sched_set->rtpset;
- mask2=(guint32*)&user_set->rtpset;
- mask3=(guint32*)&result_set->rtpset;
+ tqmask1=(guint32*)&sched_set->rtpset;
+ tqmask2=(guint32*)&user_set->rtpset;
+ tqmask3=(guint32*)&result_set->rtpset;
while(i<maxs+1){
- *mask3=(*mask1) & (*mask2); /* computes the AND between the two masks*/
+ *tqmask3=(*tqmask1) & (*tqmask2); /* computes the AND between the two tqmasks*/
/* and unset the sessions that have been found from the sched_set */
- *mask1=(*mask1) & (~(*mask3));
- if ((*mask3)!=0){
+ *tqmask1=(*tqmask1) & (~(*tqmask3));
+ if ((*tqmask3)!=0){
for (j=0;j<32;j++){
- if ( ((*mask3)>>j) & 1){
+ if ( ((*tqmask3)>>j) & 1){
ret++;
}
}
}
i+=32;
- mask1++;
- mask2++;
- mask3++;
+ tqmask1++;
+ tqmask2++;
+ tqmask3++;
}
//printf("session_set_and: ret=%i\n",ret);
return ret;
@@ -116,12 +116,12 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
SessionSet temp;
RtpScheduler *sched=ortp_get_scheduler();
- /*lock the scheduler to not read the masks while they are being modified by the scheduler*/
+ /*lock the scheduler to not read the tqmasks while they are being modified by the scheduler*/
rtp_scheduler_lock(sched);
while(1){
- /* computes the SessionSet intersection (in the other words mask intersection) between
- the mask given by the user and scheduler masks */
+ /* computes the SessionSet intersection (in the other words tqmask intersection) between
+ the tqmask given by the user and scheduler tqmasks */
if (recvs!=NULL){
bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
if (bits>0){